@@ -273,7 +273,7 @@ std::string Generation::makefile(const Langage& langage, const SVM::Outils::Exte
 		<< "	@echo \"Cleaning generated files...\"; rm -rf src/plugin.o $(DEPENDENCIES) $(GENERATED) libsvm" << extension->_nom << ".so" << liste_tests.str() << std::endl
 		<< "" << std::endl
 		<< "dist: all" << std::endl
-		<< "	@echo \"Cleaning build system...\" ; rm -rf configure.ac Makefile.* */Makefile.* plugin_install update_patches src test plugin_configuration_string 2>/dev/null" << std::endl
+		<< "	@echo \"Cleaning build system...\" ; rm -rf configure.ac Makefile.* */Makefile.* plugin_install update_patches src test plugin_configuration_string .libs 2>/dev/null" << std::endl
 		<< "" << std::endl
 		<< "libsvm" << extension->_nom << ".so: $(DEPENDENCIES) src/plugin.o" << std::endl
 		<< "\t$(COMPILER) -shared -o $@ -fPIC -DPIC -Wl,-L$(SVM) -lsvmplugininterface -Wl,-soname -Wl,libsvm" << extension->_nom << ".so $(COPTIONS) $^ $(LOPTIONS)" << std::endl
@@ -1272,11 +1272,13 @@ void ContenuPaquetExtension::construction(ConfigurationPaquet& configuration)
 	_installation = configuration.lit_booleen("plugin_install",0);
 	_garde_construction = configuration.lit_booleen("plugin_keep_build",0);
 	_joue_tests = configuration.lit_booleen("plugin_check",0);
+	_enleve_source = configuration.lit_booleen("plugin_remove_source",0);
 }
 
 void ContenuPaquetFichier::construction(ConfigurationPaquet& configuration)
 {
 	FichierPaquet::construction(configuration,_position);
+	_mode = configuration.lit_chaine("file_mode",0);
 }
 
 void ContenuPaquetConfiguration::construction(ConfigurationPaquet& configuration)
@@ -1350,12 +1352,23 @@ void ContenuPaquetExtension::generation(std::ostream& os)
 			<< "if [ $? -ne 0 ] ; then" << std::endl
 			<< "	error \"Build of plugin " << _nom << " failed.\"" << std::endl
 			<< "fi" << std::endl;
+		if(_enleve_source)
+		{
+			os	<< "rm -rf " << _destination << std::endl;
+		}
 	}
 }
 
 void ContenuPaquetFichier::generation(std::ostream& os)
 {
 	FichierPaquet::generation(os);
+	if(not _mode.empty())
+	{
+		os	<< "chmod " << _mode << " " << _destination << std::endl
+			<< "if [ $? -ne 0 ] ; then" << std::endl
+			<< "	error \"Unable to set permission mode " << _mode << " on file " <<_destination << ".\"" << std::endl
+			<< "fi" << std::endl;
+	}
 }
 
 void ContenuPaquetCode::generation(std::ostream& os)
@@ -1378,6 +1391,7 @@ void Paquet::verification()
 
 void Paquet::construction(const bool debug)
 {
+	_debug = debug;
 	ConfigurationPaquet configuration;
 	configuration.variable(AttributPaquet ("only_in_dev",{std::make_shared<ValeurOptionBooleen>(debug)}));
 	configuration.variable(AttributPaquet ("only_in_release",{std::make_shared<ValeurOptionBooleen>(not debug)}));
@@ -1474,13 +1488,22 @@ void Paquet::generation(const std::string& fichier_sortie)
 		<< "	rm -rf " << repertoire << std::endl
 		<< "fi" << std::endl
 		<< "if [ -d " << repertoire << " ] ; then" << std::endl
-		<< "	error \"Installation directory " << repertoire << " already exist.\"" << std::endl
+		<< "	error \"Installation directory " << repertoire << " already exists.\"" << std::endl
 		<< "fi" << std::endl
 		<< "mkdir -p " << repertoire << std::endl
 		<< "if [ ! -d " << repertoire << " ] ; then" << std::endl
 		<< "	error \"Impossible to create installation directory " << repertoire << " \"" << std::endl
-		<< "fi" << std::endl
-		<< "cd " << repertoire << std::endl;
+		<< "fi" << std::endl;
+	if(not _debug)
+	{
+		sp()	<< "remove_installation()" << std::endl
+			<< "{" << std::endl
+			<< "	cd .." << std::endl
+			<< "	rm -rf " << repertoire << std::endl
+			<< "}" << std::endl
+			<< "trap remove_installation EXIT" << std::endl;
+	}
+	sp()	<< "cd " << repertoire << std::endl;
 	if(_test_version_api_svm)
 	{
 		sp()	<< "log \"Checking SVM API version compatibility.\"" << std::endl
@@ -1492,6 +1515,10 @@ void Paquet::generation(const std::string& fichier_sortie)
 	{
 		c->generation(sp());
 	}
-	sp() << "log \"Installation of package " << _nom << " version " << _version << " complete in '" << repertoire << "'.\"" << std::endl;
+	sp()	<< "log \"Installation of package " << _nom << " version " << _version << " complete in '" << repertoire << "'.\"" << std::endl;
+	if(not _debug)
+	{
+		sp()	<< "trap EXIT" << std::endl;
+	}
 	sp.finalise();
 }
