@@ -617,17 +617,19 @@ struct ConfigurationPaquet
 	{
 		static std::map<std::string,DefinitionAttributPaquet> instance =
 		{
-			{ "version", { "option", { std::make_shared<ValeurOptionChaine>("1.0") }, { { ValeurOption::Type::CHAINE , ValeurOption::Type::DEFAUT } }, "Specify the package version." } },
-			{ "author", { "option", { std::make_shared<ValeurOptionChaine>("Anonymous") }, { { ValeurOption::Type::CHAINE } }, "Specify the package author." } },
-			{ "maintainer", { "option", { std::make_shared<ValeurOptionChaine>("Anonymous"), std::make_shared<ValeurOptionChaine>("a.nonymous@orga.net") }, { { ValeurOption::Type::CHAINE }, { ValeurOption::Type::CHAINE } }, "Specify the package maintainer name and email." } },
-			{ "svm_api_version_check", { "option", { std::make_shared<ValeurOptionBooleen>(true) }, { { ValeurOption::Type::BOOLEEN , ValeurOption::Type::DEFAUT } }, "Enables the check of the SVM API version compatibility with the source SVM on the target SVM." } },
-			{ "path", { "set", { std::make_shared<ValeurOptionChaine>(".") }, { { ValeurOption::Type::CHAINE , ValeurOption::Type::DEFAUT } }, "Path of creation of files within the package." } },
 			{ "app_change_sheebang", { "set", { std::make_shared<ValeurOptionBooleen>(true) }, { { ValeurOption::Type::BOOLEEN , ValeurOption::Type::DEFAUT } }, "Update the application sheebang with the path of the target SVM." } },
-			{ "app_local_plugins_root", { "set", { std::make_shared<ValeurOptionChaine>("") }, { { ValeurOption::Type::CHAINE , ValeurOption::Type::DEFAUT } }, "Change the root directory of all local plugins of applications." } },
+			{ "app_local_plugins_root", { "set", { std::make_shared<ValeurOptionChaine>("") }, { { ValeurOption::Type::CHAINE , ValeurOption::Type::DEFAUT } }, "Change the root directory of all local plugins of applications (Empty means no change)." } },
+			{ "author", { "option", { std::make_shared<ValeurOptionChaine>("Anonymous") }, { { ValeurOption::Type::CHAINE } }, "Specify the package author." } },
+			{ "end_of_file", { "set", { std::make_shared<ValeurOptionChaine>("EOF") }, { { ValeurOption::Type::CHAINE , ValeurOption::Type::DEFAUT } }, "End of file marker in installer script file." } },
+			{ "file_mode", { "set", { std::make_shared<ValeurOptionChaine>("") }, { { ValeurOption::Type::CHAINE , ValeurOption::Type::DEFAUT } }, "Permission mode for file, with chmod syntax (Empty string means system default)." } },
+			{ "maintainer", { "option", { std::make_shared<ValeurOptionChaine>("Anonymous"), std::make_shared<ValeurOptionChaine>("a.nonymous@orga.net") }, { { ValeurOption::Type::CHAINE }, { ValeurOption::Type::CHAINE } }, "Specify the package maintainer name and email." } },
+			{ "path", { "set", { std::make_shared<ValeurOptionChaine>(".") }, { { ValeurOption::Type::CHAINE , ValeurOption::Type::DEFAUT } }, "Path of creation of files within the package." } },
+			{ "plugin_check", { "set", { std::make_shared<ValeurOptionBooleen>(false) }, { { ValeurOption::Type::BOOLEEN , ValeurOption::Type::DEFAUT } }, "Run checks on local plugins during install." } },
 			{ "plugin_install", { "set", { std::make_shared<ValeurOptionBooleen>(true) }, { { ValeurOption::Type::BOOLEEN , ValeurOption::Type::DEFAUT } }, "Install local plugins." } },
 			{ "plugin_keep_build", { "set", { std::make_shared<ValeurOptionBooleen>(false) }, { { ValeurOption::Type::BOOLEEN , ValeurOption::Type::DEFAUT } }, "Keep local plugins build files." } },
-			{ "plugin_check", { "set", { std::make_shared<ValeurOptionBooleen>(false) }, { { ValeurOption::Type::BOOLEEN , ValeurOption::Type::DEFAUT } }, "Run checks on local plugins during install." } },
-			{ "end_of_file", { "set", { std::make_shared<ValeurOptionChaine>("EOF") }, { { ValeurOption::Type::CHAINE , ValeurOption::Type::DEFAUT } }, "End of file marker in installer script file." } }
+			{ "plugin_remove_source", { "set", { std::make_shared<ValeurOptionBooleen>(false) }, { { ValeurOption::Type::BOOLEEN , ValeurOption::Type::DEFAUT } }, "Remove plugin source file after installation." } },
+			{ "svm_api_version_check", { "option", { std::make_shared<ValeurOptionBooleen>(true) }, { { ValeurOption::Type::BOOLEEN , ValeurOption::Type::DEFAUT } }, "Enables the check of the SVM API version compatibility with the source SVM on the target SVM." } },
+			{ "version", { "option", { std::make_shared<ValeurOptionChaine>("1.0") }, { { ValeurOption::Type::CHAINE , ValeurOption::Type::DEFAUT } }, "Specify the package version." } }
 		};
 		return instance;
 	}
@@ -789,6 +791,7 @@ struct ContenuPaquetExtension : public ContenuPaquet, private FichierPaquet
 	bool _installation;
 	bool _garde_construction;
 	bool _joue_tests;
+	bool _enleve_source;
 };
 
 DECL_SHARED_PTR(ContenuPaquetFichier);
@@ -803,6 +806,8 @@ struct ContenuPaquetFichier : public ContenuPaquet, private FichierPaquet
 	{
 		os << "Fichier \"" << _nom << "\"";
 	}
+
+	std::string _mode;
 };
 
 DECL_SHARED_PTR(ContenuPaquetConfiguration);
@@ -888,6 +893,8 @@ struct Paquet
 		}
 		return os;
 	}
+	bool _debug;
+
 	std::string _nom;
 	std::string _licence;
 	std::vector<OptionPaquetSP> _options;
